from __future__ import absolute_import, unicode_literals
import os
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from celery import Celery

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'config.settings')
app = Celery('config')
app.config_from_object('django.conf:settings', namespace='CELERY')

REQUIRED_SETTINGS = [
    'DJANGO_CLICKHOUSE_LOGGER_HOST',
    'DJANGO_CLICKHOUSE_LOGGER_PORT',
    'DJANGO_CLICKHOUSE_LOGGER_USER',
    'DJANGO_CLICKHOUSE_LOGGER_PASSWORD'
]


def check_settings():
    for setting_name in REQUIRED_SETTINGS:
        if not hasattr(settings, setting_name):
            raise ImproperlyConfigured(
                f'Clickhouse-django-logger error: Missing required setting: {setting_name}')
    if not hasattr(settings, 'CELERY_TASK_QUEUES'):
        raise ImproperlyConfigured(
            'Clickhouse-django-logger error: Missing required setting: CELERY_TASK_QUEUES')

    task_routes = settings.CELERY_TASK_QUEUES
    if not isinstance(task_routes, dict) or 'logger' not in task_routes:
        raise ImproperlyConfigured(
            'Clickhouse-django-logger error: CELERY_TASK_QUEUES must include a route for "logger".')



from django.apps import AppConfig


class DjangoClickhouseLoggerConfig(AppConfig):
    name = 'clickhouse_django_logger'
    verbose_name = 'ClickHouse Django Logger'

    def ready(self):
        from .utils import ensure_clickhouse_db_and_table_exist
        from .config import check_settings

        check_settings()
        ensure_clickhouse_db_and_table_exist()



from setuptools import setup, find_packages

# Версия вашей библиотеки
version = '0.1.1'

# Длинное описание, которое обычно загружается из файла README.md
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='clickhouse-django-logger',
    version=version,
    author='Алексей',
    author_email='vipzenit666666@gmail.com',
    description='Логгер Django для ClickHouse с интеграцией Celery.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/single-service/clickhouse_django_logger',
    # project_urls={
    #     "Bug Tracker": "URL трекера проблем вашего проекта на GitHub",
    # },
    license='MIT',  # Или другая лицензия, если применимо
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'Django>=2.2',
        'celery',
        'requests',
    ],
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.6',
)
